#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : ernie
# @Time         : 2023/7/31 13:04
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

from pydantic import root_validator
from langchain.chat_models.openai import ChatOpenAI
from langchain.utils import get_from_dict_or_env, get_pydantic_field_names

from meutils.pipe import *
from chatllm.llmchain.completion.ernie import ErnieBotCompletion


class ErnieBot(ChatOpenAI):
    client: Any  #: :meta private:
    model_name: str = Field(default="ernie-turbo", alias="model")
    openai_api_key: Optional[str] = Field(default=None, alias="ernie_api_key")  # ernie_api_key: Optional[str] = None

    class Config:
        """Configuration for this pydantic object."""

        allow_population_by_field_name = True

    @root_validator()
    def validate_environment(cls, values: Dict) -> Dict:
        """Validate that api key and python package exists in environment."""
        values["ernie_api_key"] = get_from_dict_or_env(
            values, "ernie_api_key", "ERNIE_API_KEY"
        )
        values["openai_api_key"] = values["ernie_api_key"]  # 覆盖 openai_api_key

        values["client"] = ErnieBotCompletion

        if values["n"] < 1:
            raise ValueError("n must be at least 1.")
        if values["n"] > 1 and values["streaming"]:
            raise ValueError("n must be 1 when streaming.")
        return values

    @property
    def _llm_type(self) -> str:
        return Path(__file__).name  # 'ernie'


if __name__ == '__main__':
    from meutils.pipe import *
    from langchain.chains import LLMChain  # 导入LLM链。
    from langchain.prompts import ChatPromptTemplate  # 导入聊天提示模板

    first_prompt = ChatPromptTemplate.from_template(
        "{xx}"
    )

    llm = ErnieBot()
    c = LLMChain(llm=llm, prompt=first_prompt)
    c.run('你是谁')
